==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/ChaikinOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { ChaikinOscillatorIndicatorStrategy } from "./ChaikinOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var ChaikinOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ChaikinOscillatorIndicator, _super);
    function ChaikinOscillatorIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChaikinOscillatorIndicator.prototype.get_up = function () {
        return new ChaikinOscillatorIndicatorStrategy();
    };
    Object.defineProperty(ChaikinOscillatorIndicator.prototype, "up", {
        get: function () {
            return this.get_up();
        },
        enumerable: false,
        configurable: true
    });
    ChaikinOscillatorIndicator.prototype.get_u2 = function () {
        return ChaikinOscillatorIndicator.$;
    };
    Object.defineProperty(ChaikinOscillatorIndicator.prototype, "u2", {
        get: function () {
            return this.get_u2();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ChaikinOscillatorIndicator.prototype, "shortPeriod", {
        get: function () {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.vb));
        },
        set: function (a) {
            this.h(ChaikinOscillatorIndicator.vb, a);
        },
        enumerable: false,
        configurable: true
    });
    ChaikinOscillatorIndicator.prototype.ux = function () {
        return this.shortPeriod;
    };
    Object.defineProperty(ChaikinOscillatorIndicator.prototype, "longPeriod", {
        get: function () {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.va));
        },
        set: function (a) {
            this.h(ChaikinOscillatorIndicator.va, a);
        },
        enumerable: false,
        configurable: true
    });
    ChaikinOscillatorIndicator.prototype.uu = function () {
        return this.longPeriod;
    };
    ChaikinOscillatorIndicator.$t = markType(ChaikinOscillatorIndicator, 'ChaikinOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    ChaikinOscillatorIndicator.vb = StrategyBasedIndicator.u9(3, ChaikinOscillatorIndicator.$);
    ChaikinOscillatorIndicator.va = StrategyBasedIndicator.u5(10, ChaikinOscillatorIndicator.$);
    return ChaikinOscillatorIndicator;
}(StrategyBasedIndicator));
export { ChaikinOscillatorIndicator };

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm5/lib/ChaikinOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { ChaikinOscillatorIndicatorStrategy } from "./ChaikinOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var ChaikinOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ChaikinOscillatorIndicator, _super);
    function ChaikinOscillatorIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChaikinOscillatorIndicator.prototype.get_yy = function () {
        return new ChaikinOscillatorIndicatorStrategy();
    };
    Object.defineProperty(ChaikinOscillatorIndicator.prototype, "yy", {
        get: function () {
            return this.get_yy();
        },
        enumerable: false,
        configurable: true
    });
    ChaikinOscillatorIndicator.prototype.get_zb = function () {
        return ChaikinOscillatorIndicator.$;
    };
    Object.defineProperty(ChaikinOscillatorIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ChaikinOscillatorIndicator.prototype, "shortPeriod", {
        get: function () {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.zk));
        },
        set: function (a) {
            this.h(ChaikinOscillatorIndicator.zk, a);
        },
        enumerable: false,
        configurable: true
    });
    ChaikinOscillatorIndicator.prototype.y6 = function () {
        return this.shortPeriod;
    };
    Object.defineProperty(ChaikinOscillatorIndicator.prototype, "longPeriod", {
        get: function () {
            return typeGetValue(this.c(ChaikinOscillatorIndicator.zj));
        },
        set: function (a) {
            this.h(ChaikinOscillatorIndicator.zj, a);
        },
        enumerable: false,
        configurable: true
    });
    ChaikinOscillatorIndicator.prototype.y3 = function () {
        return this.longPeriod;
    };
    ChaikinOscillatorIndicator.$t = markType(ChaikinOscillatorIndicator, 'ChaikinOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    ChaikinOscillatorIndicator.zk = StrategyBasedIndicator.zi(3, ChaikinOscillatorIndicator.$);
    ChaikinOscillatorIndicator.zj = StrategyBasedIndicator.ze(10, ChaikinOscillatorIndicator.$);
    return ChaikinOscillatorIndicator;
}(StrategyBasedIndicator));
export { ChaikinOscillatorIndicator };
